@@ -288,6 +288,7 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
      * @throws ezcBaseValueException
      *         If a non numeric row ID is requested.
      */
+    #[ReturnTypeWillChange]
     public function offsetExists( $offset )
     {
         if ( !is_int( $offset ) || $offset < 0 )
@@ -312,6 +313,7 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
      * @throws ezcBaseValueException
      *         If a non numeric row ID is requested.
      */
+    #[ReturnTypeWillChange]
     public function offsetGet( $offset )
     {
         $offset = ( $offset === null ) ? count( $this->rows ) : $offset;
@@ -340,6 +342,7 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
      * @throws ezcBaseValueException
      *         If the provided value is not of type {@link ezcConsoleTableRow}.
      */
+    #[ReturnTypeWillChange]
     public function offsetSet( $offset, $value )
     {
         if ( !( $value instanceof ezcConsoleTableRow ) )
@@ -368,6 +371,7 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
      * @throws ezcBaseValueException
      *         If a non numeric row ID is requested.
      */
+    #[ReturnTypeWillChange]
     public function offsetUnset( $offset )
     {
         if ( !is_int( $offset ) || $offset < 0 )
@@ -387,6 +391,7 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
      *
      * @return int Number of cells in this row.
      */
+    #[ReturnTypeWillChange]
     public function count()
     {
         $keys = array_keys( $this->rows );
@@ -401,6 +406,7 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
      *
      * @return ezcConsoleTableCell The currently selected cell.
      */
+    #[ReturnTypeWillChange]
     public function current()
     {
         return current( $this->rows );
@@ -414,6 +420,7 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
      *
      * @return int The key of the currently selected cell.
      */
+    #[ReturnTypeWillChange]
     public function key()
     {
         return key( $this->rows );
@@ -427,6 +434,7 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
      *
      * @return mixed ezcConsoleTableCell if the next cell exists, or false.
      */
+    #[ReturnTypeWillChange]
     public function next()
     {
         return next( $this->rows );
@@ -440,6 +448,7 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
      *
      * @return ezcConsoleTableCell The very first cell of this row.
      */
+    #[ReturnTypeWillChange]
     public function rewind()
     {
         return reset( $this->rows );
@@ -453,6 +462,7 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
      *
      * @return ezcConsoleTableCell The very first cell of this row.
      */
+    #[ReturnTypeWillChange]
     public function valid()
     {
         return current( $this->rows ) !== false;
@@ -775,10 +785,14 @@ class ezcConsoleTable implements Countable, Iterator, ArrayAccess
             return array( $this->width );
         }
 
-        $borderWidth = iconv_strlen(
-            $this->properties['options']->lineHorizontal,
-            'UTF-8'
-        );
+        $borderWidth = 0;
+        if ( is_string( $this->properties['options']->lineHorizontal ) )
+        {
+            $borderWidth = iconv_strlen(
+                $this->properties['options']->lineHorizontal,
+                'UTF-8'
+            );
+        }
 
         // Subtract border and padding chars from global width
         $globalWidth = $this->width
