@@ -9,9 +9,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -28,7 +28,7 @@
 return array (
   0 => '[0mPlease enter your email address:  [0m',
   1 => '[0mPlease enter your email address:  [0m',
-  2 => 'User manually aborted\\ņ',
+  2 => "User manually aborted\n",
 );
 
-?>
\ No newline at end of file
+?>
